
// viewView.cpp : implementation of the CviewView class
//

#include "stdafx.h"
// SHARED_HANDLERS can be defined in an ATL project implementing preview, thumbnail
// and search filter handlers and allows sharing of document code with that project.
#ifndef SHARED_HANDLERS
#include "view.h"
#endif

#include "viewDoc.h"
#include "viewView.h"

#include <cmath>

#ifdef _DEBUG
#define new DEBUG_NEW
#endif


// CviewView

IMPLEMENT_DYNCREATE(CviewView, CView)

BEGIN_MESSAGE_MAP(CviewView, CView)
	// Standard printing commands
	ON_COMMAND(ID_FILE_PRINT, &CView::OnFilePrint)
	ON_COMMAND(ID_FILE_PRINT_DIRECT, &CView::OnFilePrint)
	ON_COMMAND(ID_FILE_PRINT_PREVIEW, &CviewView::OnFilePrintPreview)
	ON_WM_CONTEXTMENU()
	ON_WM_RBUTTONUP()
END_MESSAGE_MAP()

// CviewView construction/destruction

CviewView::CviewView()
{
	// TODO: add construction code here

}

CviewView::~CviewView()
{
}

BOOL CviewView::PreCreateWindow(CREATESTRUCT& cs)
{
	// TODO: Modify the Window class or styles here by modifying
	//  the CREATESTRUCT cs

	return CView::PreCreateWindow(cs);
}

// CviewView drawing

void CviewView::OnDraw(CDC* pDC)
{
    CviewDoc* pDoc = GetDocument();
    ASSERT_VALID(pDoc);
    if (!pDoc)
        return;

    // TODO: add draw code for native data here

    int angles = 360;
    int bins   = 512;

    const double radius = 100.0; // size of circle on screen

    const double angle_inc = 2.0*3.14159267 / static_cast<double>(angles);
    const double bin_inc   = radius  / static_cast<double>(bins);

    const double xcenter = radius;
    const double ycenter = radius;

    for(int i=0; i<angles; ++i)
    {
        for(int j=0; j<bins; ++j)
        {
            double angle1 = angle_inc * i;
            double angle2 = angle_inc * (i+1);
            double r1 = bin_inc * j;
            double r2 = bin_inc * (j+1);
            CPoint pts[4];
            pts[0].x = xcenter + r1 * cos(angle1);
            pts[0].y = ycenter + r1 * sin(angle1);
            pts[1].x = xcenter + r2 * cos(angle1);
            pts[1].y = ycenter + r2 * sin(angle1);
            pts[2].x = xcenter + r2 * cos(angle2);
            pts[2].y = ycenter + r2 * sin(angle2);
            pts[3].x = xcenter + r1 * cos(angle2);
            pts[3].y = ycenter + r1 * sin(angle2);

            // fill in the polygon consisting of the points:
            // (x1,y1) , (x2,y2) , (x3,y3) , (x4,y4)
            CRgn region;
            region.CreatePolygonRgn(pts, 4, ALTERNATE);
            CBrush blueBrush;
            blueBrush.CreateSolidBrush(RGB(0, 0, 255));
            pDC->FillRgn(&region, &blueBrush);
        }
    }

}


// CviewView printing


void CviewView::OnFilePrintPreview()
{
#ifndef SHARED_HANDLERS
	AFXPrintPreview(this);
#endif
}

BOOL CviewView::OnPreparePrinting(CPrintInfo* pInfo)
{
	// default preparation
	return DoPreparePrinting(pInfo);
}

void CviewView::OnBeginPrinting(CDC* /*pDC*/, CPrintInfo* /*pInfo*/)
{
	// TODO: add extra initialization before printing
}

void CviewView::OnEndPrinting(CDC* /*pDC*/, CPrintInfo* /*pInfo*/)
{
	// TODO: add cleanup after printing
}

void CviewView::OnRButtonUp(UINT /* nFlags */, CPoint point)
{
	ClientToScreen(&point);
	OnContextMenu(this, point);
}

void CviewView::OnContextMenu(CWnd* /* pWnd */, CPoint point)
{
#ifndef SHARED_HANDLERS
	theApp.GetContextMenuManager()->ShowPopupMenu(IDR_POPUP_EDIT, point.x, point.y, this, TRUE);
#endif
}


// CviewView diagnostics

#ifdef _DEBUG
void CviewView::AssertValid() const
{
	CView::AssertValid();
}

void CviewView::Dump(CDumpContext& dc) const
{
	CView::Dump(dc);
}

CviewDoc* CviewView::GetDocument() const // non-debug version is inline
{
	ASSERT(m_pDocument->IsKindOf(RUNTIME_CLASS(CviewDoc)));
	return (CviewDoc*)m_pDocument;
}
#endif //_DEBUG


// CviewView message handlers
